yakumo.nova.v2.security_group_rule

Package yakumo :: Package nova :: Package v2 :: Module security_group_rule |
[hide private]
[frames] | no frames]

# Module security_group_rule

source code

Resource class and its manager for security group rules in Compute API v2

Classes | [hide private]
| Resource Resource class for security group rules in Compute API v2
| Manager Manager class for security group rules in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('remote_ip_prefix', 'ip_range', mapper.No
      op), ('port_range_min', 'from_port', mapper.Noop), ('port_range_max',
      'to_port', mapper.Noop), ('protocol', 'ip_protocol', mapper.Noop), ('g
      roup', 'group', mapper.Noop), ('project', 'tenant_id', mapper.Resource
      ('project')),]